@@ -26,7 +26,8 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-
+#include <sched.h>
+#include <sys/prctl.h>
 #include <asm/unistd.h>
 
 #include <curl/curl.h>
@@ -90,13 +91,18 @@ static DBusHandlerResult got_message(
 	return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
 
-void dbus_ask_permission(void)
+void dbus_ask_permission(char * detail_file_name)
 {
 	DBusMessage *message;
 	if (!bus)
 		return;
 	message = dbus_message_new_signal("/org/kerneloops/submit/permission",
 			"org.kerneloops.submit.permission", "ask");
+	if (detail_file_name) {
+		dbus_message_append_args(message,
+			DBUS_TYPE_STRING, &detail_file_name,
+			DBUS_TYPE_INVALID);
+	}
 	dbus_connection_send(bus, message, NULL);
 	dbus_message_unref(message);
 }
@@ -126,6 +132,13 @@ int main(int argc, char**argv)
 	DBusError error;
 	int godaemon = 1;
 
+/*
+ * Signal the kernel that we're not timing critical
+ */
+#ifdef PR_SET_TIMERSLACK,1000
+	prctl(PR_SET_TIMERSLACK,1000*1000*1000, 0, 0, 0);
+#endif
+
 	read_config_file("/etc/kerneloops.conf");
 
 	if (argc > 1 && strstr(argv[1], "--nodaemon"))
@@ -137,7 +150,6 @@ int main(int argc, char**argv)
 		opted_in = 2;
 	}
 
-
 	if (!opted_in && !testmode) {
 		fprintf(stderr, " [Inactive by user preference]");
 		return EXIT_SUCCESS;
@@ -155,11 +167,11 @@ int main(int argc, char**argv)
 	curl_global_init(CURL_GLOBAL_ALL);
 */
 
-
 	if (godaemon && daemon(0, 0)) {
 		printf("kerneloops failed to daemonize.. exiting \n");
 		return EXIT_FAILURE;
 	}
+	sched_yield();
 
 	loop = g_main_loop_new(NULL, FALSE);
 	dbus_error_init(&error);
@@ -171,10 +183,11 @@ int main(int argc, char**argv)
 		dbus_connection_add_filter(bus, got_message, NULL, NULL);
 	}
 
-
-
 	/* we scan dmesg before /var/log/messages; dmesg is a more accurate source normally */
 	scan_dmesg(NULL);
+	/* during boot... don't go too fast and slow the system down */
+	if (!testmode)
+		sleep(10);
 	scan_filename("/var/log/messages", 1);
 
 	if (argc > 2 && strstr(argv[1], "--file"))
